<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>CustomCommandOptDlg</name>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="112"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="114"/>
        <source>Command:</source>
        <translation>Befehl:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="116"/>
        <source>Shortcuts:</source>
        <translation>Tastenkürzel:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="127"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="128"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="205"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="211"/>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="154"/>
        <source>Add Command</source>
        <translation>Befehl hinzufügen </translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="160"/>
        <source>Edit Command</source>
        <translation>Befehl bearbeiten</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="170"/>
        <source>Delete Command</source>
        <translation>Befehl löschen</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="191"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="193"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="195"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="372"/>
        <source>Please enter a name</source>
        <translation>Bitte einen Namen eingeben</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="386"/>
        <source>Please enter a command</source>
        <translation>Bitte einen Befehl eingeben</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="436"/>
        <source>The name already exists,</source>
        <translation>Der Name existiert bereits,</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="437"/>
        <source>please input another one.</source>
        <translation>bitte einen anderen eingeben.</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="618"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CustomCommandPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="212"/>
        <source>Add Command</source>
        <translation>Befehl hinzufügen </translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="216"/>
        <source>No commands yet</source>
        <translation>Noch keine Befehle</translation>
    </message>
</context>
<context>
    <name>CustomCommandPlugin</name>
    <message>
        <location filename="../src/customcommand/customcommandplugin.cpp" line="50"/>
        <source>Custom commands</source>
        <translation>Benutzerdefinierte Befehle</translation>
    </message>
</context>
<context>
    <name>CustomCommandSearchRstPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandsearchrstpanel.cpp" line="146"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>CustomThemeSettingDialog</name>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="236"/>
        <source>Custom Theme</source>
        <translation>Benutzerdefiniertes Thema</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="260"/>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="264"/>
        <source>Light</source>
        <translation>Hell</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="269"/>
        <source>Dark</source>
        <translation>Dunkel</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="323"/>
        <source>Fore color:</source>
        <translation>Vordergrundfarbe:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="330"/>
        <source>Back color:</source>
        <translation>Hintergrundfarbe:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="348"/>
        <source>Prompt PS1:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="352"/>
        <source>Prompt PS2:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="423"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="431"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Bestätigen</translation>
    </message>
</context>
<context>
    <name>ListView</name>
    <message>
        <location filename="../src/views/listview.cpp" line="298"/>
        <source>Delete Server</source>
        <translation>Server löschen</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="298"/>
        <location filename="../src/views/listview.cpp" line="492"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Sind Sie sicher, dass Sie %1 löschen möchten?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="269"/>
        <location filename="../src/main/mainwindow.cpp" line="324"/>
        <source>New window</source>
        <translation>Neues Fenster </translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="339"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="755"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="757"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1829"/>
        <source>Type path to download file</source>
        <translation>Geben Sie den Pfad zum Herunterladen der Datei ein</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="2135"/>
        <source>Custom Theme</source>
        <translation>Benutzerdefiniertes Thema</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/views/listview.cpp" line="304"/>
        <location filename="../src/views/listview.cpp" line="493"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="236"/>
        <location filename="../src/common/utils.cpp" line="244"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="305"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="494"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="241"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Bestätigen</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="514"/>
        <location filename="../src/settings/settings_translation.cpp" line="109"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Close workspace</source>
        <translation>Arbeitsfläche schließen</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="517"/>
        <location filename="../src/settings/settings_translation.cpp" line="105"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Close other workspaces</source>
        <translation>Andere Arbeitsflächen schließen</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1177"/>
        <source>Could not find &quot;%1&quot;, starting &quot;%2&quot; instead. Please check your shell profile.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1183"/>
        <source>Could not open &quot;%1&quot;, unable to run it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1185"/>
        <source>Could not find &quot;%1&quot;, unable to run it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1215"/>
        <source>Output has been suspended by pressing Ctrl+S. Pressing Ctrl+Q to resume.</source>
        <translation>Die Ausgabe wurde durch Drücken von Strg+S unterbrochen. Zum Fortsetzen Strg+Q drücken.</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="132"/>
        <location filename="../src/settings/settings_translation.cpp" line="133"/>
        <source>Tab title format</source>
        <translation>Tab-Titel-Format</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="134"/>
        <location filename="../src/settings/settings_translation.cpp" line="135"/>
        <source>Remote tab title format</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/tabrenamedlg.cpp" line="203"/>
        <location filename="../src/views/tabbar.cpp" line="504"/>
        <location filename="../src/settings/settings_translation.cpp" line="81"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Rename title</source>
        <translation>Titel umbenennen</translation>
    </message>
    <message>
        <location filename="../src/views/tabbar.cpp" line="498"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Close tab</source>
        <translation>Tab schließen</translation>
    </message>
    <message>
        <location filename="../src/views/tabbar.cpp" line="501"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Close other tabs</source>
        <translation>Andere Tabs schließen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="33"/>
        <source>Copy on select</source>
        <translation>Kopieren bei Auswahl</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="35"/>
        <source>Cursor blink</source>
        <translation>Cursorblinkgeschwindigkeit</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="37"/>
        <source>Cursor style</source>
        <translation>Mauszeiger-Stil</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="39"/>
        <source>Scroll on keystroke</source>
        <translation>Bildlauf bei Tastendruck</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="41"/>
        <source>Scroll on output</source>
        <translation>Bildlauf bei Ausgabe</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="43"/>
        <source>Hide Quake window after losing focus</source>
        <translation>Verstecke das Quake-Fenster, nachdem der Fokus verloren wurde</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="45"/>
        <location filename="../src/main/service.cpp" line="159"/>
        <source>Blur background</source>
        <translation>Hintergrund weichzeichnen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="47"/>
        <source>Use on starting</source>
        <translation>Beim Startvorgang verwenden</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="49"/>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="51"/>
        <source>Font size</source>
        <translation>Schriftgröße</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="53"/>
        <location filename="../src/main/service.cpp" line="182"/>
        <source>Opacity</source>
        <translation>Deckkraft</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="55"/>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="57"/>
        <source>Cursor</source>
        <translation>Mauszeiger</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="59"/>
        <source>Scroll</source>
        <translation>Bildlauf</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="61"/>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="63"/>
        <source>Basic</source>
        <translation>Basis</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="65"/>
        <source>Interface</source>
        <translation>Schnittstelle</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="67"/>
        <source>Shortcuts</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="69"/>
        <location filename="../src/main/mainwindow.cpp" line="1671"/>
        <source>Others</source>
        <translation>Andere</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="71"/>
        <location filename="../src/main/terminalapplication.cpp" line="36"/>
        <location filename="../src/main/mainwindow.cpp" line="1669"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="73"/>
        <source>Workspace</source>
        <translation>Arbeitsfläche</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="75"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Custom commands</source>
        <translation>Benutzerdefinierte Befehle</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="77"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Display shortcuts</source>
        <translation>Tastenkürzel anzeigen </translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="79"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Remote management</source>
        <translation>Fernverwaltung</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="83"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="85"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="87"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Default size</source>
        <translation>Standardgröße</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="89"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="91"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="93"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Select all</source>
        <translation>Alles auswählen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="95"/>
        <source>Jump to next command</source>
        <translation>Zum nächsten Befehl springen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="97"/>
        <source>Jump to previous command</source>
        <translation>Zum vorherigen Befehl springen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="99"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Zoom in</source>
        <translation>Hineinzoomen:</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="101"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Zoom out</source>
        <translation>Hinauszoomen:</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="103"/>
        <source>Close other windows</source>
        <translation>Andere Fenster schließen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="107"/>
        <source>Close window</source>
        <translation>Fenster schließen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="111"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Horizontal split</source>
        <translation>Horizontal teilen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="113"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>New tab</source>
        <translation>Neuer Tab</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="115"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Next tab</source>
        <translation>Nächster Tab</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="117"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Previous tab</source>
        <translation>Vorheriger Tab</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="119"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Select left workspace</source>
        <translation>Linke Arbeitsfläche auswählen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="121"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select lower workspace</source>
        <translation>Untere Arbeitsfläche auswählen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="123"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Select right workspace</source>
        <translation>Rechte Arbeitsfläche auswählen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="125"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select upper workspace</source>
        <translation>Obere Arbeitsfläche auswählen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="127"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Vertical split</source>
        <translation>Vertikal teilen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="129"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Find</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="131"/>
        <source>Tab titles</source>
        <translation>Tab-Titel</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="137"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 1</source>
        <translation>Gehe zu Tab 1</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="139"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 2</source>
        <translation>Gehe zu Tab 2</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="141"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 3</source>
        <translation>Gehe zu Tab 3</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="143"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 4</source>
        <translation>Gehe zu Tab 4</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="145"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 5</source>
        <translation>Gehe zu Tab 5</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="147"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 6</source>
        <translation>Gehe zu Tab 6</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="149"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 7</source>
        <translation>Gehe zu Tab 7</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="151"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 8</source>
        <translation>Gehe zu Tab 8</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="153"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 9</source>
        <translation>Gehe zu Tab 9</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="155"/>
        <source>Disable flow control using Ctrl+S, Ctrl+Q</source>
        <translation>Flusskontrolle mit Strg+S, Strg+Q deaktivieren</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="157"/>
        <source>Shell profile</source>
        <translation>Shell-Profile</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="517"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="379"/>
        <source>The name should be no more than 32 characters</source>
        <translation>Der Name sollte nicht länger als 32 Zeichen sein</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="583"/>
        <source>Select the private key file</source>
        <translation>Private Schlüsseldatei auswählen</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="587"/>
        <location filename="../src/main/mainwindow.cpp" line="1851"/>
        <location filename="../src/common/utils.cpp" line="133"/>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <location filename="../src/main/terminalapplication.cpp" line="39"/>
        <source>Terminal is an advanced terminal emulator with workspace, multiple windows, remote management, quake mode and other features.</source>
        <translation>Terminal ist ein fortschrittlicher Terminalemulator mit Arbeitsbereich, mehreren Fenstern, Fernverwaltung, Quake-Modus und anderen Funktionen.</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1667"/>
        <source>Tabs</source>
        <translation>Tabs</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1687"/>
        <source>Switch focus to &quot;+&quot; icon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select tab</source>
        <translation>Tab auswählen</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1775"/>
        <location filename="../src/common/utils.cpp" line="148"/>
        <source>Select file to upload</source>
        <translation>Datei zum Hochladen auswählen</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1782"/>
        <location filename="../src/common/utils.cpp" line="153"/>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1845"/>
        <location filename="../src/common/utils.cpp" line="127"/>
        <source>Select a directory to save the file</source>
        <translation>Ein Verzeichnis zum Speichern der Datei auswählen</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="403"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="621"/>
        <location filename="../src/common/utils.cpp" line="254"/>
        <source>please set another one.</source>
        <translation>bitte einen anderen festlegen.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="173"/>
        <location filename="../src/common/utils.cpp" line="207"/>
        <source>Close this terminal?</source>
        <translation>Dieses Terminal schließen?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="174"/>
        <location filename="../src/common/utils.cpp" line="208"/>
        <source>There is still a process running in this terminal. Closing the terminal will kill it.</source>
        <translation>Es läuft immer noch ein Prozess in diesem Terminal. Das Schließen des Terminals wird ihn beenden.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="178"/>
        <location filename="../src/common/utils.cpp" line="212"/>
        <source>There are still %1 processes running in this terminal. Closing the terminal will kill all of them.</source>
        <translation>Es laufen noch %1 Prozesse in diesem Terminal. Das Schließen des Terminals wird alle Prozesse beenden.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="183"/>
        <location filename="../src/common/utils.cpp" line="203"/>
        <source>Close this window?</source>
        <translation>Dieses Fenster schließen?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="184"/>
        <location filename="../src/common/utils.cpp" line="204"/>
        <source>There are still processes running in this window. Closing the window will kill all of them.</source>
        <translation>Es laufen noch Prozesse in diesem Fenster. Das Schließen des Fensters wird alle Prozesse beenden.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>Programs are still running in terminal</source>
        <translation>Es werden noch Programme im Terminal ausgeführt</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>Are you sure you want to uninstall it?</source>
        <translation>Sind Sie sicher, dass Sie es deinstallieren möchten?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="234"/>
        <location filename="../src/common/utils.cpp" line="238"/>
        <source>Are you sure you want to uninstall this application?</source>
        <translation>Sind Sie sicher, dass Sie diese Anwendung deinstallieren möchten?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="235"/>
        <location filename="../src/common/utils.cpp" line="239"/>
        <source>You will not be able to use Terminal any longer.</source>
        <translation>Sie können das Terminal nicht länger verwenden.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="245"/>
        <location filename="../src/common/utils.cpp" line="289"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="323"/>
        <source>Set the work directory</source>
        <translation>Arbeitsverzeichnis festlegen</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="326"/>
        <source>Set the window mode on starting</source>
        <translation>Fenstermodus beim Start festlegen</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="329"/>
        <source>Execute a command in the terminal</source>
        <translation>Einen Befehl im Terminal ausführen</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="332"/>
        <source>Run script string in the terminal</source>
        <translation>Skriptzeichenfolge im Terminal ausführen</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="335"/>
        <source>Run in quake mode</source>
        <translation>Im Quake-Modus ausführen</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="338"/>
        <source>Keep terminal open when command finishes</source>
        <translation>Terminal offen lassen, wenn der Befehl abgeschlossen ist</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="201"/>
        <source>Add Server</source>
        <translation>Server hinzufügen </translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="205"/>
        <source>No servers yet</source>
        <translation>Noch keine Server</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPlugin</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="90"/>
        <source>Remote management</source>
        <translation>Fernverwaltung</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="216"/>
        <source>Make sure that rz and sz commands have been installed in the server before right clicking to upload and download files.</source>
        <translation>Bitte stellen Sie sicher, dass die Befehle rz und sz auf dem Server installiert sind, bevor Sie mit der rechten Maustaste klicken, um Dateien hoch- oder herunterzuladen.</translation>
    </message>
</context>
<context>
    <name>RemoteManagementSearchPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementsearchpanel.cpp" line="225"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>ServerConfigOptDlg</name>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="70"/>
        <source>Advanced options</source>
        <translation>Erweiterte Optionen </translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="108"/>
        <source>Add Server</source>
        <translation>Server hinzufügen </translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="144"/>
        <source>Server name:</source>
        <translation>Servername:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="146"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="156"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="184"/>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="154"/>
        <source>Address:</source>
        <translation>Adresse:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="161"/>
        <source>Port:</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="182"/>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="189"/>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="195"/>
        <source>Certificate:</source>
        <translation>Zertifikat:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="211"/>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="217"/>
        <source>Path:</source>
        <translation>Pfad:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="223"/>
        <source>Command:</source>
        <translation>Befehl:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="229"/>
        <source>Encoding:</source>
        <translation>Kodierung:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="235"/>
        <source>Backspace key:</source>
        <translation>Rücklauftaste:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="241"/>
        <source>Delete key:</source>
        <translation>Taste löschen:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="247"/>
        <source>Delete server</source>
        <translation>Server löschen</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="261"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="262"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="266"/>
        <source>Edit Server</source>
        <translation>Server bearbeiten</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="267"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="511"/>
        <source>Please enter a server name</source>
        <translation>Bitte einen Servername eingeben</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="524"/>
        <source>Please enter an IP address</source>
        <translation>Bitte eine IP-Adresse eingeben</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="529"/>
        <source>Please enter a port</source>
        <translation>Bitte einen Port eingeben</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="535"/>
        <source>Please enter a username</source>
        <translation>Bitte einen Benutzernamen eingeben</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="549"/>
        <source>The server name already exists,</source>
        <translation>Der Servername existiert bereits,</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="550"/>
        <source>please input another one. </source>
        <translation>bitte einen anderen eingeben.</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <location filename="../src/main/service.cpp" line="399"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Normal window</source>
        <translation>Normales Fenster</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Split screen</source>
        <translation>Geteilter Bildschirm</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
</context>
<context>
    <name>ShortcutManager</name>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="283"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="292"/>
        <source>The shortcut %1 is invalid, </source>
        <translation>Das Kürzel %1 ist ungültig, </translation>
    </message>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="299"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="306"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="312"/>
        <source>The shortcut %1 was already in use, </source>
        <translation>Das Tastenkürzel %1 ist bereits in Verwendung,</translation>
    </message>
</context>
<context>
    <name>TabRenameWidget</name>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="60"/>
        <source>Insert</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="109"/>
        <source>username: %u</source>
        <translation>Benutzername: %u</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <source>username@: %U</source>
        <translation>Benutzername@: %U</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <source>remote host: %h</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="96"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="108"/>
        <source>session number: %#</source>
        <translation>Sitzungsnummer: %#</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="96"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="110"/>
        <source>title set by shell: %w</source>
        <translation>Titel durch Shell festgelegt: %w</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="107"/>
        <source>program name: %n</source>
        <translation>Programmname: %n</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="107"/>
        <source>current directory (short): %d</source>
        <translation>aktuelles Verzeichnis (kurz): %d</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="108"/>
        <source>current directory (long): %D</source>
        <translation>aktuelles Verzeichnis (lang): %D</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="109"/>
        <source>local host: %h</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TermWidget</name>
    <message>
        <location filename="../src/views/termwidget.cpp" line="483"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="486"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="495"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="499"/>
        <source>Open in file manager</source>
        <translation>Im Dateimanager öffnen</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="508"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>Horizontal split</source>
        <translation>Horizontal teilen</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="511"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>Vertical split</source>
        <translation>Vertikal teilen</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="521"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>New tab</source>
        <translation>Neuer Tab</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="528"/>
        <source>Exit fullscreen</source>
        <translation>Vollbild beenden</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="530"/>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="533"/>
        <source>Find</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="537"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="547"/>
        <source>Encoding</source>
        <translation>Kodierung</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>Custom commands</source>
        <translation>Benutzerdefinierte Befehle</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="551"/>
        <source>Remote management</source>
        <translation>Fernverwaltung</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="555"/>
        <source>Upload file</source>
        <translation>Datei hochladen</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="556"/>
        <source>Download file</source>
        <translation>Datei herunterladen </translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="561"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="189"/>
        <location filename="../src/common/utils.cpp" line="223"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="191"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="224"/>
        <location filename="../src/common/utils.cpp" line="256"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
</TS>